@@ -164,9 +164,12 @@ class WorkerAgent(BaseAgent):
     def __init__(self, goal: str, tools_json: List, agent_config: Dict, work_dir: str, cache_messages: Union[bool, List[Dict]], broker: MessageBroker, listen_topic: str, publish_topic: str, status_topic: str):
         super().__init__(goal, tools_json, agent_config, work_dir, cache_messages, broker, listen_topic, publish_topic, status_topic)
 
-        if self.cache_messages and isinstance(self.cache_messages, list) and len(self.cache_messages) > 1:
-            first_user_message = replace_xml_content(self.cache_messages[1]["content"], "goal", goal)
-            self.config["cache_messages"] = self.cache_messages[0:1] + [{"role": "user", "content": first_user_message}] + self.cache_messages[2:]
+        if self.cache_messages and isinstance(self.cache_messages, Messages) and len(self.cache_messages) > 1:
+            if self.cache_messages.provider("goal"):
+                self.cache_messages.provider("goal").update(goal)
+            else:
+                self.cache_messages[1].insert(0, Goal(goal))
+            self.config["cache_messages"] = self.cache_messages
 
         self.agent = chatgpt(**self.config)
 
@@ -191,6 +194,9 @@ class WorkerAgent(BaseAgent):
         except InputTokenCountExceededError as e:
             self.broker.publish({"status": "error", "result": "The request body is too long, please try again."}, self.status_topic)
             return
+        except BadRequestError as e:
+            self.broker.publish({"status": "error", "result": "Bad request error!"}, self.status_topic)
+            return
         except RetryFailedError as e:
             self.logger.error("❌ Worker retry failed, retrying...")
             self.broker.publish(message, self.error_topic)
@@ -201,8 +207,7 @@ class WorkerAgent(BaseAgent):
             self.broker.publish(message, self.error_topic)
         else:
             self.broker.publish({"status": "new_message", "result": "\n✅ 工作智能体:\n" + response}, self.status_topic)
-            if len(self.agent.conversation["default"]) > 1 and self.agent.conversation["default"][-1].role == "user":
-                self.agent.conversation["default"].pop(-1)
+            self.agent.conversation["default"][-1].rstrip(Texts)
             self.broker.publish({
                 "conversation": self.agent.conversation["default"]
             }, self.publish_topic)
