@@ -1434,6 +1434,281 @@ Files: {Files(visible=True, name="files")}
         self.assertTrue(message in messages_collection)
         self.assertFalse(UserMessage("not in collection") in messages_collection)
 
+    async def test_zz_none_input_ignored(self):
+        """测试在Message初始化时，None值是否被自动忽略"""
+        # 1. 在初始化列表中包含 None
+        message = UserMessage("Hello", None, "World")
+        self.assertEqual(len(message.provider()), 2)
+        self.assertIsInstance(message.provider()[0], Texts)
+        self.assertIsInstance(message.provider()[1], Texts)
+        rendered = await message.render_latest()
+        self.assertEqual(rendered['content'], "HelloWorld")
+
+        # 2. 测试只有 None
+        message_none = SystemMessage(None)
+        self.assertEqual(len(message_none.provider()), 0)
+        self.assertFalse(message_none)
+
+        # 3. 测试混合 provider 和 None
+        message_mixed = SystemMessage(Texts("hi"), None)
+        self.assertEqual(len(message_mixed.provider()), 1)
+        self.assertIsInstance(message_mixed.provider()[0], Texts)
+
+    async def test_zaa_has_method_for_provider_type_check(self):
+        """测试 Message.has(type) 方法是否能正确检查 provider 类型"""
+        # 1. 创建一个混合类型的消息
+        message_with_text = UserMessage(Texts("hi"), Images("url"))
+
+        # 2. 测试存在的情况
+        # This line is expected to fail with an AttributeError before implementation
+        self.assertTrue(message_with_text.has(Texts))
+        self.assertTrue(message_with_text.has(Images))
+
+        # 3. 测试不存在的情况
+        self.assertFalse(message_with_text.has(Tools))
+
+        # 4. 测试空消息
+        empty_message = UserMessage()
+        self.assertFalse(empty_message.has(Texts))
+
+        # 5. 测试传入无效类型
+        with self.assertRaises(TypeError):
+            message_with_text.has(str)
+
+        with self.assertRaises(TypeError):
+            # Also test with a class that is not a subclass of ContextProvider
+            class NotAProvider: pass
+            message_with_text.has(NotAProvider)
+
+    async def test_zab_lstrip_and_rstrip(self):
+        """测试 lstrip, rstrip, 和 strip 方法是否能正确移除两侧的特定类型的 provider"""
+        # 1. 定义一个用于测试的子类
+        class SpecialTexts(Texts):
+            pass
+        url = "data:image/png;base64,FAKE_IMG"
+
+        # 2. 创建一个复杂的测试消息
+        message = UserMessage(
+            Texts("leading1"),
+            Texts("leading2"),
+            Images(url, name="image1"),
+            Texts("middle"),
+            SpecialTexts("special_middle"),
+            Images(url, name="image2"),
+            Texts("trailing1"),
+            SpecialTexts("special_trailing"), # rstrip(Texts) should stop here
+            Texts("trailing2")
+        )
+
+        # 3. 测试 rstrip(Texts)
+        r_stripped_message = UserMessage(*message.provider()) # 创建副本
+        r_stripped_message.rstrip(Texts)
+        # 应移除 "trailing2"，但在 "special_trailing" 处停止
+        self.assertEqual(len(r_stripped_message), 8)
+        self.assertIs(type(r_stripped_message[-1]), SpecialTexts)
+
+        # 4. 测试 lstrip(Texts)
+        l_stripped_message = UserMessage(*message.provider()) # 创建副本
+        l_stripped_message.lstrip(Texts)
+        # 应移除 "leading1" 和 "leading2"，但在 "image1" 处停止
+        self.assertEqual(len(l_stripped_message), 7)
+        self.assertIs(type(l_stripped_message[0]), Images)
+
+        # 5. 测试 strip(Texts)
+        stripped_message = UserMessage(*message.provider()) # 创建副本
+        stripped_message.strip(Texts)
+        # 应同时移除 "leading1", "leading2", 和 "trailing2"
+        self.assertEqual(len(stripped_message), 6)
+        self.assertIs(type(stripped_message[0]), Images)
+        self.assertIs(type(stripped_message[-1]), SpecialTexts)
+
+        # 6. 测试在一个只包含一种类型的消息上进行剥离
+        only_texts = UserMessage(Texts("a"), Texts("b"))
+        only_texts.strip(Texts)
+        self.assertEqual(len(only_texts), 0)
+
+        # 7. 测试剥离一个不包含目标类型的消息
+        only_images = UserMessage(Images("url1"), Images("url2"))
+        only_images.strip(Texts)
+        self.assertEqual(len(only_images), 2) # 不应改变
+
+        # 8. 测试在一个空消息上进行剥离
+        empty_message = UserMessage()
+        empty_message.strip(Texts)
+        self.assertEqual(len(empty_message), 0)
+
+        # 9. 测试剥离子类
+        message_ending_with_special = UserMessage(Texts("a"), SpecialTexts("b"))
+        message_ending_with_special.rstrip(SpecialTexts)
+        self.assertEqual(len(message_ending_with_special), 1)
+        self.assertIsInstance(message_ending_with_special[0], Texts)
+
+    async def test_zac_texts_join_parameter(self):
+        """测试 Texts provider 是否支持通过参数控制拼接方式"""
+        # 1. 测试默认行为：直接拼接
+        message_default = UserMessage(
+            Texts("First line."),
+            Texts("Second line.")
+        )
+        rendered_default = await message_default.render_latest()
+        self.assertEqual(rendered_default['content'], "First line.Second line.")
+
+        # 2. 测试新功能：使用 \n\n 拼接
+        # 假设新参数为 `newline=True`
+        message_newline = UserMessage(
+            Texts("First paragraph."),
+            Texts("Second paragraph.", newline=True)
+        )
+        rendered_newline = await message_newline.render_latest()
+        self.assertEqual(rendered_newline['content'], "First paragraph.\n\nSecond paragraph.")
+
+        # 3. 测试多个 provider 的情况
+        message_multiple = UserMessage(
+            Texts("First."),
+            Texts("Second.", newline=True),
+            Texts("Third.", newline=True)
+        )
+        rendered_multiple = await message_multiple.render_latest()
+        self.assertEqual(rendered_multiple['content'], "First.\n\nSecond.\n\nThird.")
+
+        # 4. 测试只有一个 provider 的情况
+        message_single = UserMessage(
+            Texts("Only one.", newline=True)
+        )
+        rendered_single = await message_single.render_latest()
+        self.assertEqual(rendered_single['content'], "Only one.")
+
+    async def test_zad_simple_render_without_refresh(self):
+        """测试 Messages(UserMessage('hi')).render() 是否能直接同步渲染"""
+        # This test checks if a simple message can be rendered synchronously
+        # without an explicit `await refresh()` or `await render_latest()`.
+        # Calling the synchronous render method directly on a new instance
+        rendered = Messages(UserMessage("hi", Images(url="data:image/png;base64,FAKE"))).render()
+
+        # The current implementation will likely fail here, returning []
+        self.assertEqual(len(rendered), 1)
+        self.assertEqual(rendered[0]['role'], 'user')
+
+        # Now we expect a list for multimodal content
+        content = rendered[0]['content']
+        self.assertIsInstance(content, list)
+        self.assertEqual(len(content), 2)
+        self.assertEqual(content[0]['type'], 'text')
+        self.assertEqual(content[0]['text'], 'hi')
+        self.assertEqual(content[1]['type'], 'image_url')
+        self.assertEqual(content[1]['image_url']['url'], "data:image/png;base64,FAKE")
+
+    async def test_zae_messages_representation(self):
+        """测试 Messages 对象的 __repr__ 方法是否提供可读的输出"""
+        messages = Messages(
+            UserMessage("Hello"),
+            AssistantMessage("Hi there!")
+        )
+
+        actual_repr = repr(messages)
+
+        # 一个可读的字符串形式应该像 Messages([...]) 这样，并包含其内部 message 的 repr
+        self.assertTrue(actual_repr.startswith("Messages(["), f"期望输出以 'Messages([' 开头，但得到 '{actual_repr}'")
+        self.assertTrue(actual_repr.endswith("])"), f"期望输出以 '])' 结尾，但得到 '{actual_repr}'")
+        self.assertIn("Message(role='user', items=", actual_repr)
+        self.assertIn("Message(role='assistant', items=", actual_repr)
+
+    async def test_zaf_message_absorption(self):
+        """测试Message对象是否能吸收嵌套的Message对象作为其内容"""
+        # 1. ToolResults吸收UserMessage
+        tool_results_1 = ToolResults(tool_call_id="call_1", content=UserMessage("hi"))
+        rendered_1 = await tool_results_1.render_latest()
+        self.assertEqual(rendered_1['content'], "hi")
+        self.assertEqual(rendered_1['tool_call_id'], "call_1")
+
+        # 2. UserMessage吸收AssistantMessage
+        user_message_1 = UserMessage("prefix", AssistantMessage("absorbed content"))
+        rendered_user_1 = await user_message_1.render_latest()
+        self.assertEqual(rendered_user_1['content'], "prefixabsorbed content")
+        self.assertEqual(len(user_message_1.provider()), 2) # Should be flattened
+
+        # 3. 复杂嵌套
+        final_message = ToolResults(tool_call_id="call_final", content=UserMessage("A", AssistantMessage("B", UserMessage("C"))))
+        rendered_final = await final_message.render_latest()
+        self.assertEqual(rendered_final['content'], "ABC")
+
+        # 4. 组合情况: ToolResults(UserMessage(Texts("a"), Texts("b"))) -> content="ab"
+        tool_results_2 = ToolResults(tool_call_id="call_2", content=UserMessage(Texts("a"), Texts("b")))
+        rendered_2 = await tool_results_2.render_latest()
+        self.assertEqual(rendered_2['content'], "ab")
+
+        # 5. 包含多模态内容的情况 (ToolResults应该只提取文本)
+        tool_results_3 = ToolResults(tool_call_id="call_3", content=UserMessage("text part", Images(url="some_url")))
+        rendered_3 = await tool_results_3.render_latest()
+        self.assertEqual(rendered_3['content'], "text part") # Images should be ignored
+
+        # 6. 直接传入字符串的情况应保持不变
+        tool_results_4 = ToolResults(tool_call_id="call_4", content="just a string")
+        rendered_4 = await tool_results_4.render_latest()
+        self.assertEqual(rendered_4['content'], "just a string")
+
+        # 7. 传入一个空的 Message
+        tool_results_5 = ToolResults(tool_call_id="call_5", content=UserMessage())
+        rendered_5 = await tool_results_5.render_latest()
+        self.assertEqual(rendered_5['content'], "")
+
+    async def test_zzb_final_message_render_logic(self):
+        """
+        最终版测试:
+        - render() 首次调用保证获取完整结果。
+        - 后续 render() 调用返回缓存结果，不会自动刷新。
+        - refresh() 显式刷新内容。
+        - render_latest() 总是获取最新内容。
+        """
+        from datetime import datetime
+        import time
+
+        # 1. 创建带有动态 provider 的 Message
+        timestamp_provider = Texts(lambda: str(datetime.now().timestamp()))
+        message = UserMessage("Time: ", timestamp_provider)
+
+        # 2. 第一次调用 render() - 应该刷新并返回完整内容
+        rendered_1 = await message.render()
+        content1 = rendered_1['content']
+        timestamp1_str = content1.replace("Time: ", "")
+        self.assertTrue(timestamp1_str, "render() 第一次调用应返回完整动态内容")
+
+        # 3. 第二次调用 render() - 不应自动刷新，返回缓存的内容
+        time.sleep(1)
+        rendered_2 = await message.render()
+        content2 = rendered_2['content']
+        self.assertEqual(content1, content2, "第二次调用 render() 应返回缓存内容，不应刷新")
+
+        # 4. 调用 refresh() - 显式刷新
+        time.sleep(1)
+        await message.refresh()
+
+        # 5. refresh() 后调用 render() - 应该返回刚刚刷新的新内容
+        rendered_3 = await message.render()
+        content3 = rendered_3['content']
+        timestamp3_str = content3.replace("Time: ", "")
+        self.assertNotEqual(content2, content3, "refresh() 后 render() 应返回新内容")
+
+        # 6. 调用 render_latest() - 总是获取最新内容
+        time.sleep(1)
+        rendered_latest = await message.render_latest()
+        content_latest = rendered_latest['content']
+        timestamp_latest_str = content_latest.replace("Time: ", "")
+        self.assertNotEqual(content3, content_latest, "render_latest() 应总是获取最新内容")
+
+        # 7. 测试 ToolResults
+        tool_results_msg = ToolResults(tool_call_id="call_123", content="Result from tool")
+        # ToolResults's content is static, so render() should always return the same full content
+        rendered_tool_1 = await tool_results_msg.render()
+        self.assertEqual(rendered_tool_1, {
+            "role": "tool",
+            "tool_call_id": "call_123",
+            "content": "Result from tool"
+        })
+        # Subsequent calls should also work
+        rendered_tool_2 = await tool_results_msg.render()
+        self.assertEqual(rendered_tool_1, rendered_tool_2)
+
 
 # ==============================================================================
 # 6. 演示
