@@ -10,7 +10,7 @@ import warnings
 from pathlib import Path
 from collections import Counter, defaultdict, namedtuple
 
-from ..aient.src.aient.plugins import register_tool
+from ..aient.aient.plugins import register_tool
 
 from tqdm import tqdm
 from diskcache import Cache
